| Title: | TOPSIS method for multiple-criteria decision making (MCDM) |
|---|---|
| Description: | Evaluation of alternatives based on multiple criteria using TOPSIS method. |
| Authors: | Mahmoud Mosalman Yazdi |
| Maintainer: | Mahmoud Mosalman Yazdi <[email protected]> |
| License: | GPL-2 |
| Version: | 1.0 |
| Built: | 2026-06-07 08:58:03 UTC |
| Source: | https://github.com/cran/topsis |
The Technique for Order of Preference by Similarity to Ideal Solution (TOPSIS) is a multiple-criteria decision making (MCDM) method.
topsis(decision = NULL, weights = NULL, impacts = NULL)topsis(decision = NULL, weights = NULL, impacts = NULL)
decision |
A numeric matrix with m rows for m alternatives and n columns for n criterions. |
weights |
A numeric vector with length equal to number of columns in decision matrix for weights of criterions. |
impacts |
A character vector of "+" and "-" signs for the way that each criterion influences on the alternatives. |
A data frame including elements
alt.row |
Row number of alternatives in decision matrix. |
score |
TOPSIS score of alternatives. |
rank |
Rank of alternatives based on TOPSIS scores. |
Mahmoud Mosalman Yazdi <[email protected]>
Yoon, K.P.; Hwang, C. (1995). _Multiple Attribute Decision Making: An Introduction_. California: SAGE publications.
d <- matrix(rpois(12, 5), nrow = 4) w <- c(1, 1, 2) i <- c("+", "-", "+") topsis(d, w, i)d <- matrix(rpois(12, 5), nrow = 4) w <- c(1, 1, 2) i <- c("+", "-", "+") topsis(d, w, i)