Welcome to ClientVPS Mirrors

Help for package topsis
Type: Package
Title: TOPSIS method for multiple-criteria decision making (MCDM)
Version: 1.0
Date: 2013-09-24
Author: Mahmoud Mosalman Yazdi
Maintainer: Mahmoud Mosalman Yazdi <m.mosalman@gmail.com>
Description: Evaluation of alternatives based on multiple criteria using TOPSIS method.
License: GPL-2
Packaged: 2013-09-30 17:28:07 UTC; mahmoud
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2013-09-30 20:15:19

TOPSIS method for multiple-criteria decision making (MCDM)

Description

The Technique for Order of Preference by Similarity to Ideal Solution (TOPSIS) is a multiple-criteria decision making (MCDM) method.

Usage

topsis(decision = NULL, weights = NULL, impacts = NULL)

Arguments

decision

A numeric matrix with m rows for m alternatives and n columns for n criterions.

weights

A numeric vector with length equal to number of columns in decision matrix for weights of criterions.

impacts

A character vector of "+" and "-" signs for the way that each criterion influences on the alternatives.

Value

A data frame including elements

alt.row

Row number of alternatives in decision matrix.

score

TOPSIS score of alternatives.

rank

Rank of alternatives based on TOPSIS scores.

Author(s)

Mahmoud Mosalman Yazdi <m.mosalman@gmail.com>

References

Yoon, K.P.; Hwang, C. (1995). _Multiple Attribute Decision Making: An Introduction_. California: SAGE publications.

Examples

d <- matrix(rpois(12, 5), nrow = 4)
w <- c(1, 1, 2)
i <- c("+", "-", "+")
topsis(d, w, i)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.